@@ -1,7 +1,7 @@
 package CHI;
 BEGIN {
-  $CHI::VERSION = '0.54';
-}
+  $CHI::VERSION = '0.55';
+}    ## no critic (Moose::RequireMakeImmutable)
 use 5.006;
 use Carp;
 use CHI::Stats;
@@ -180,7 +180,7 @@ CHI - Unified cache handling interface
 
 =head1 VERSION
 
-version 0.54
+version 0.55
 
 =head1 SYNOPSIS
 
@@ -342,8 +342,6 @@ An object to use for serializing keys that are references. See L</serializer>
 above for the different ways this can be passed in. The default is to use JSON
 in canonical mode (sorted hash keys).
 
-=for html <a name="label">
-
 =item label [STRING]
 
 A label for the cache as a whole, independent of namespace - e.g.
@@ -365,8 +363,6 @@ due to file system limits. For most drivers there is no maximum.
 
 Add an mirror cache as a subcache. See L</SUBCACHES>.
 
-=for html <a name="namespace">
-
 =item namespace [STRING]
 
 Identifies a namespace that all cache entries for this object will be in. This
@@ -526,8 +522,6 @@ or else a duration treated as an I<expires_in> value described below. If it is
 a hash reference, it may contain one or more of the following options. Most of
 these options can be provided with defaults in the cache constructor.
 
-=for html <a name="expires_in">
-
 =over
 
 =item expires_in [DURATION]
@@ -535,14 +529,10 @@ these options can be provided with defaults in the cache constructor.
 Amount of time from now until this data expires. I<DURATION> may be an integer
 number of seconds or a L<duration expression|/DURATION EXPRESSIONS>.
 
-=for html <a name="expires_at">
-
 =item expires_at [INT]
 
 The epoch time at which the data expires.
 
-=for html <a name="expires_variance">
-
 =item expires_variance [FLOAT]
 
 Controls the variable expiration feature, which allows items to expire a little
@@ -584,8 +574,6 @@ as soon as it is determined to be expired. But it's something to be aware of.
 
 =back
 
-=for html <a name="compute">
-
 =item compute( $key, $options, $code )
 
 Combines the C<get> and C<set> operations in a single call. Attempts to get
@@ -793,8 +781,6 @@ cache.
 
 =head2 Property accessors
 
-=for html <a name="chi_root_class">
-
 =over
 
 =item chi_root_class( )
